# vim: set sw=4 ts=4 et nu:
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           pogo
Version:        1.0
Release:        pm150500.2.1
Summary:        Simple Audio Player
Source0:        %{name}-%{version}.tar.xz
URL:            https://github.com/jendrikseipp/pogo
Group:          Productivity/Multimedia/Sound/Players
License: GPL-2.0
BuildRequires:  pkgconfig(python3)
BuildRequires:  update-desktop-files
Requires:       python3-Pillow
Requires:       python3-dbus-python
Requires:       python3-gobject
Requires:       python3-gst
Requires:       python3-mutagen
BuildArch:      noarch

%description
Pogo is probably the simplest and fastest audio player for Linux. Its
elementary-inspired design uses the screen-space very efficiently. Pogo is
especially well-suited for people who organize their music by albums on the
hard drive. The main interface components are a directory tree and a playlist
that groups albums in an innovative way.

%prep
%autosetup -p1

%build
sed -i~ "s|/usr/bin/env.*|$(type -P python3)|g" 'pogo.py'
diff -u "$_"~ "$_" && exit 1
exit 0

%install
make \
    DESTDIR="%{buildroot}" \
    INSTALL="$(type -P install)" \
    MAKE="$(type -P make)" \
    RM="$(type -P rm)" \
    prefix="%{_prefix}" \
    install


%suse_update_desktop_file -r "%{name}" AudioVideo Player

pushd '%{buildroot}'
for i in .%{_datadir}/locale/*
do
  test -d "$i" || continue
  test -d "/$i" && continue
  rm -rfv "$i"
done
popd
%find_lang "%{name}"

%files -f "%{name}.lang"
%doc NEWS.md
%license LICENSE.txt
%{_bindir}/pogo
%{_datadir}/pogo
%{_datadir}/applications/pogo.desktop
%{_datadir}/pixmaps/pogo.png
%{_mandir}/man*/*

%changelog
* Mon Jan 13 2020 olaf@aepfle.de
- update to 1.0
* Thu Sep  6 2012 pascal.bleser@opensuse.org
- update to 0.8:
  * Control pogo from the commandline. The commands play, pause, next, prev and
    stop are supported. (lp:986164)
  * When pogo is started with tracks on the commandline, append the tracks to
    the old playlist.
  * Start playback automatically at startup by calling "pogo play".
  * Prevent automatic playback when tracks are given on the commandline with
    "pogo MyFile.mp3 pause".
  * Delete corrupted cover file if a cover cannot be correctly resized.
  * Do not try to update missing rows when a search is made quickly after
    startup.
  * Do not change volume level (sets volume to max in Fedora).
  * Highlight the parts of the query all at once to fix false highlighting.
  * Update translations.
* Sat Apr 28 2012 pascal.bleser@opensuse.org
- update to 0.7:
  * improves the search: searches in the home folder if it hasn't found
    anything in the music directories, and does not search in subdirectories if
    it already searched in the parent directory; only shows the filename and at
    most one parent directory for each file in the search results
* Mon Mar 26 2012 pascal.bleser@opensuse.org
- update to 0.6: too many changes, please read ChangeLog
* Sun Mar 13 2011 detlef@links2linux.de
- update to 0.4
* Mon Dec 27 2010 pascal.bleser@opensuse.org
- initial version (0.3.1)
